#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_TOINT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_TOINT_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/toint.hpp>

#endif
